/**
 *
 * @(#)author  [ok]
 * @(#)version 1.0
 * @(#)date    2014. 06. 18
 * @(#)since   JDK 1.7.2
 *
 * Copyright (c) www.udapsoft.co.kr, Inc.
 * All rights reserved.
 * This software is the proprietary information of udapsoft, Inc.
 */
package kr.co.udapsoft.ebid.buyer.payment.outside.biz;


import kr.co.hsnc.common.base.WAFLogger;
import kr.co.hsnc.common.sql.RowSet;
import kr.co.hsnc.common.sql.RowSetImpl;
import kr.co.hsnc.common.sql.search.Search;
import kr.co.hsnc.common.sql.search.SearchImpl;
import kr.co.hsnc.common.util.ValueObject;

import com.udapsoft.waf.common.ui.InitCombo;
import com.udapsoft.waf.system.Biz;
import com.udapsoft.waf.system.HandlerStorage;

public class AdvencePaymentListInitBiz extends Biz {
	
	public AdvencePaymentListInitBiz(HandlerStorage storage) {
		super(storage);
	}

	public void doBiz() throws Exception {

		WAFLogger.debug("대금관리.외주대금.선급금관리 리스트 페이지 INIT");
		
		//검색 조건에 ComboBox데이터 설정 [상태]
		RowSet rowSet = getPerpayStatus_searchCombo();
		storage.addRowSet("statusComboList", rowSet);
		
		//시트의 ComboBox데이터 설정 [상태]
		ValueObject vo = getPerpayStatus_sheetCombo();
		storage.addObject("selectText", vo.getObject("DETAILCD"));
		storage.addObject("selectValue", vo.getObject("DETAILNM"));
		
		//시트의 ComboBox데이터 설정 [신청구분]
		vo = getPerpayReqDiv_sheetCombo();
		storage.addObject("selectText1", vo.getObject("DETAILCD"));
		storage.addObject("selectValue1", vo.getObject("DETAILNM"));
		
		//시트의 ComboBox데이터 설정 [세금계산서 발행방법]
		vo = getTaxMethodCd_sheetCombo();
		storage.addObject("selectText2", vo.getObject("DETAILCD"));
		storage.addObject("selectValue2", vo.getObject("DETAILNM"));

		storage.setSuccess(true);
	}

    /**
     * 선급금 신청 상태Combox 데이터를 조회 한다.
	 * @param 
	 * @param 
	 * @return ValueObject
	 */
	public RowSet getPerpayStatus_searchCombo(){

        Search search = new SearchImpl();
        RowSet listRowSet = null;
        String sqlstr = "";
        
        try {
            sqlstr += " SELECT DETAILCD, DETAILNM             		\n"
                    + " FROM EBID_COM911T      						\n"
                    + " WHERE BASECD = 'PREPAY_STATUS_CD'      		\n"
                    + " AND DETAILCD NOT IN('10', '11')      		\n"
		            + " ORDER BY DETAILCD      						\n";
             
            search.setStatement(sqlstr);
            listRowSet = search.execute();
			
		}catch(Exception e){
			e.printStackTrace();
		}finally{

			if( listRowSet == null ){
            	listRowSet = new RowSetImpl();
            }
            
			return listRowSet;
		}
	}
	
    /**
     * 선급금 신청 상태를 조회 한다.
	 * @param 
	 * @param 
	 * @return ValueObject
	 */
	public ValueObject getPerpayStatus_sheetCombo(){

		ValueObject vo = new ValueObject();
		try{
			RowSet rowSet = getPerpayStatus_searchCombo();
			
			InitCombo initCombo  = new InitCombo();
			initCombo.makeComboData(rowSet,"DETAILCD", "DETAILNM");
		
			vo.set("DETAILCD", initCombo.getCode());
			vo.set("DETAILNM", initCombo.getCodeName());
		    
		}catch(Exception e){
			e.printStackTrace();
		}finally{
			if( vo == null ){
				vo = new ValueObject();
            }
			return vo;
		}
		
	}
	
	/**
     * 세금계산서 발행방법 Combo
	 * @param 
	 * @param 
	 * @return ValueObject
	 */
	public ValueObject getTaxMethodCd_sheetCombo(){

		ValueObject vo = new ValueObject();
		//String RIGHT_ID = "";
		//String RIGHT_NAME = "";
		try{
			RowSet rowSet = getTaxMethodCd();
			
			InitCombo initCombo  = new InitCombo();
			initCombo.makeComboData(rowSet,"DETAILCD", "DETAILNM"); 
		
			vo.set("DETAILCD", initCombo.getCode());
			vo.set("DETAILNM", initCombo.getCodeName());
		    
		}catch(Exception e){
			e.printStackTrace();
		}finally{
			if( vo == null ){
				vo = new ValueObject();
            }
			return vo;
		}
	}
	
	/**
     * 세금계산서 발행방법 
	 * @param 
	 * @param 
	 * @return ValueObject
	 */
	public RowSet getTaxMethodCd(){

        Search search = new SearchImpl();
        RowSet listRowSet = null;
        String sqlstr = "";
        
        try {
            sqlstr	+= 	" SELECT DETAILCD, DETAILNM         \n"
                    + 	"   FROM EBID_COM911T      			\n"
                    + 	"  WHERE BASECD = 'TAX_METHOD_CD'	\n";
             
            search.setStatement(sqlstr);
            listRowSet = search.execute();
			
		}catch(Exception e){
			e.printStackTrace();
		}finally{

			if( listRowSet == null ){
            	listRowSet = new RowSetImpl();
            }
            
			return listRowSet;
		}
	}

	
    /**
     * 선급금 신청 신청구분를 조회 한다.
	 * @param 
	 * @param 
	 * @return ValueObject
	 */
	public RowSet getPerpayReqDiv(){

        Search search = new SearchImpl();
        RowSet listRowSet = null;
        String sqlstr = "";
        
        try {
            sqlstr += " SELECT DETAILCD, DETAILNM             	\n"
                    + " FROM EBID_COM911T      					\n"
                    + " WHERE BASECD = 'REG_DIV_CD'     		\n";
             
            search.setStatement(sqlstr);
            listRowSet = search.execute();
			
		}catch(Exception e){
			e.printStackTrace();
		}finally{

			if( listRowSet == null ){
            	listRowSet = new RowSetImpl();
            }
            
			return listRowSet;
		}
	}
	
    /**
     * 선급금 신청구분를 조회 한다.
	 * @param 
	 * @param 
	 * @return ValueObject
	 */
	public ValueObject getPerpayReqDiv_sheetCombo(){

		ValueObject vo = new ValueObject();
		//String RIGHT_ID = "";
		//String RIGHT_NAME = "";
		try{
			RowSet rowSet = getPerpayReqDiv();
			
			InitCombo initCombo  = new InitCombo();
			initCombo.makeComboData(rowSet,"DETAILCD", "DETAILNM");
		
			vo.set("DETAILCD", initCombo.getCode());
			vo.set("DETAILNM", initCombo.getCodeName());
		    
		}catch(Exception e){
			e.printStackTrace();
		}finally{
			if( vo == null ){
				vo = new ValueObject();
            }
			return vo;
		}
	}
	
}
